from enum import Enum


class Exchanges(Enum):
    NSE_INDEX = "NSE_INDEX"
    NSE_EQ = "NSE_EQ"
    NCD_FO = "NCD_FO"
    NSE_FO = "NSE_FO"

    BSE_INDEX = "BSE_INDEX"
    BSE_EQ = "BSE_EQ"
    BCD_FO = "BCD_FO"
    BSE_FO = "BSE_FO"

    MCX_FO = "MCX_FO"

    @classmethod
    def has_value(cls, value):
        return any(value == item.value for item in cls)




import logging
import os

_logger = logging.getLogger('websocket')
_logger.addHandler(logging.NullHandler())

logging.getLogger(__name__).addHandler(logging.StreamHandler())
LOG_LEVEL = os.environ.get('LOGLEVEL', 'INFO').upper()
logging._checkLevel(LOG_LEVEL)
logging.getLogger(__name__).setLevel(LOG_LEVEL)
logger = logging.getLogger("upstox_api")
logger.debug("Log Level :: %s", LOG_LEVEL)


from setuptools import setup
setup(
  name = 'upstox',
  packages = ['upstox_api', 'upstox_api.constants'],
  version = '2.0.1',
  include_package_data=True,
  description = 'Official Python library for Upstox APIs',
  author = 'Upstox Development Team',
  author_email = 'support@upstox.com',
  url = 'https://github.com/upstox/upstox-python',
  install_requires=['future', 'requests', 'websocket_client'],
  keywords = ['upstox', 'python', 'sdk', 'trading', 'stock markets'],
  classifiers=[
    'Intended Audience :: Developers',
    'Natural Language :: English',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: Implementation :: PyPy',
    'Topic :: Software Development :: Libraries :: Python Modules'
  ],
)